Struct FindIter

struct FindIter<'a, 'h, A> { ... }

An iterator of non-overlapping matches in a particular haystack.

This iterator yields matches according to the MatchKind used by this automaton.

This iterator is constructed via the Automaton::try_find_iter method.

The type variable A refers to the implementation of the Automaton trait used to execute the search.

The lifetime 'a refers to the lifetime of the Automaton implementation.

The lifetime 'h refers to the lifetime of the haystack being searched.

Implementations

impl<'a, 'h, A> Freeze for FindIter<'a, 'h, A>

impl<'a, 'h, A> RefUnwindSafe for FindIter<'a, 'h, A>

impl<'a, 'h, A> Send for FindIter<'a, 'h, A>

impl<'a, 'h, A> Sync for FindIter<'a, 'h, A>

impl<'a, 'h, A> Unpin for FindIter<'a, 'h, A>

impl<'a, 'h, A> UnsafeUnpin for FindIter<'a, 'h, A>

impl<'a, 'h, A> UnwindSafe for FindIter<'a, 'h, A>

impl<'a, 'h, A: $crate::fmt::Debug> Debug for FindIter<'a, 'h, A>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, 'h, A: Automaton> Iterator for FindIter<'a, 'h, A>

fn next(self: &mut Self) -> Option<Match>

impl<I> IntoIterator for FindIter<'a, 'h, A>

fn into_iter(self: Self) -> I

impl<T> Any for FindIter<'a, 'h, A>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FindIter<'a, 'h, A>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FindIter<'a, 'h, A>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for FindIter<'a, 'h, A>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for FindIter<'a, 'h, A>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FindIter<'a, 'h, A>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FindIter<'a, 'h, A>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>