Struct StreamFindIter

struct StreamFindIter<'a, A, R> { ... }

An iterator that reports matches in a stream.

This iterator yields elements of type io::Result<Match>, where an error is reported if there was a problem reading from the underlying stream. The iterator terminates only when the underlying stream reaches EOF.

This iterator is constructed via the Automaton::try_stream_find_iter method.

The type variable A refers to the implementation of the Automaton trait used to execute the search.

The type variable R refers to the io::Read stream that is being read from.

The lifetime 'a refers to the lifetime of the Automaton implementation.

Implementations

impl<'a, A, R> Freeze for StreamFindIter<'a, A, R>

impl<'a, A, R> RefUnwindSafe for StreamFindIter<'a, A, R>

impl<'a, A, R> Send for StreamFindIter<'a, A, R>

impl<'a, A, R> Sync for StreamFindIter<'a, A, R>

impl<'a, A, R> Unpin for StreamFindIter<'a, A, R>

impl<'a, A, R> UnsafeUnpin for StreamFindIter<'a, A, R>

impl<'a, A, R> UnwindSafe for StreamFindIter<'a, A, R>

impl<'a, A: $crate::fmt::Debug, R: $crate::fmt::Debug> Debug for StreamFindIter<'a, A, R>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, A: Automaton, R: std::io::Read> Iterator for StreamFindIter<'a, A, R>

fn next(self: &mut Self) -> Option<Result<Match>>

impl<I> IntoIterator for StreamFindIter<'a, A, R>

fn into_iter(self: Self) -> I

impl<T> Any for StreamFindIter<'a, A, R>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for StreamFindIter<'a, A, R>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for StreamFindIter<'a, A, R>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for StreamFindIter<'a, A, R>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for StreamFindIter<'a, A, R>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for StreamFindIter<'a, A, R>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for StreamFindIter<'a, A, R>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>