Enum AhoCorasickKind
enum AhoCorasickKind
The type of Aho-Corasick implementation to use in an AhoCorasick
searcher.
This is principally used as an input to the
AhoCorasickBuilder::start_kind method. Its documentation goes into more
detail about each choice.
Variants
-
NoncontiguousNFA Use a noncontiguous NFA.
-
ContiguousNFA Use a contiguous NFA.
-
DFA Use a DFA. Warning: DFAs typically use a large amount of memory.
Implementations
impl Clone for AhoCorasickKind
fn clone(self: &Self) -> AhoCorasickKind
impl Copy for AhoCorasickKind
impl Debug for AhoCorasickKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for AhoCorasickKind
impl Freeze for AhoCorasickKind
impl PartialEq for AhoCorasickKind
fn eq(self: &Self, other: &AhoCorasickKind) -> bool
impl RefUnwindSafe for AhoCorasickKind
impl Send for AhoCorasickKind
impl StructuralPartialEq for AhoCorasickKind
impl Sync for AhoCorasickKind
impl Unpin for AhoCorasickKind
impl UnsafeUnpin for AhoCorasickKind
impl UnwindSafe for AhoCorasickKind
impl<T> Any for AhoCorasickKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for AhoCorasickKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for AhoCorasickKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for AhoCorasickKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for AhoCorasickKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for AhoCorasickKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for AhoCorasickKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for AhoCorasickKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for AhoCorasickKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>