Anchored

Enum Anchored 

#[non_exhaustive]
pub enum Anchored { No, Yes, }
The type of anchored search to perform.

If an Aho-Corasick searcher does not support the anchored mode selected, then the search will return an error or panic, depending on whether a fallible or an infallible routine was called.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


No

Run an unanchored search. This means a match may occur anywhere at or after the start position of the search up until the end position of the search.



Yes

Run an anchored search. This means that a match must begin at the start position of the search and end before the end position of the search.

Implementations

Source

impl Anchored

pub fn is_anchored(&self) -> bool

Returns true if and only if this anchor mode corresponds to an anchored search.

Example
use aho_corasick::Anchored;

assert!(!Anchored::No.is_anchored());
assert!(Anchored::Yes.is_anchored());