Struct FindIter

struct FindIter<'a, 'h>(_)

An iterator of non-overlapping matches in a particular haystack.

This iterator yields matches according to the MatchKind used by this automaton.

This iterator is constructed via the AhoCorasick::find_iter and AhoCorasick::try_find_iter methods.

The lifetime 'a refers to the lifetime of the AhoCorasick automaton.

The lifetime 'h refers to the lifetime of the haystack being searched.

Implementations

impl<'a, 'h> Debug for FindIter<'a, 'h>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, 'h> Freeze for FindIter<'a, 'h>

impl<'a, 'h> Iterator for FindIter<'a, 'h>

fn next(self: &mut Self) -> Option<Match>

impl<'a, 'h> RefUnwindSafe for FindIter<'a, 'h>

impl<'a, 'h> Send for FindIter<'a, 'h>

impl<'a, 'h> Sync for FindIter<'a, 'h>

impl<'a, 'h> Unpin for FindIter<'a, 'h>

impl<'a, 'h> UnsafeUnpin for FindIter<'a, 'h>

impl<'a, 'h> UnwindSafe for FindIter<'a, 'h>

impl<I> IntoIterator for FindIter<'a, 'h>

fn into_iter(self: Self) -> I

impl<T> Any for FindIter<'a, 'h>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FindIter<'a, 'h>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FindIter<'a, 'h>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for FindIter<'a, 'h>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for FindIter<'a, 'h>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FindIter<'a, 'h>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FindIter<'a, 'h>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>