Struct StreamFindIter
struct StreamFindIter<'a, R>(_)
An iterator that reports Aho-Corasick matches in a stream.
This iterator yields elements of type Result<Match, std::io::Error>,
where an error is reported if there was a problem reading from the
underlying stream. The iterator terminates only when the underlying stream
reaches EOF.
This iterator is constructed via the AhoCorasick::stream_find_iter and
AhoCorasick::try_stream_find_iter methods.
The type variable R refers to the io::Read stream that is being read
from.
The lifetime 'a refers to the lifetime of the corresponding
AhoCorasick searcher.
Implementations
impl<'a, R> Freeze for StreamFindIter<'a, R>
impl<'a, R> RefUnwindSafe for StreamFindIter<'a, R>
impl<'a, R> Send for StreamFindIter<'a, R>
impl<'a, R> Sync for StreamFindIter<'a, R>
impl<'a, R> Unpin for StreamFindIter<'a, R>
impl<'a, R> UnsafeUnpin for StreamFindIter<'a, R>
impl<'a, R> UnwindSafe for StreamFindIter<'a, R>
impl<'a, R: $crate::fmt::Debug> Debug for StreamFindIter<'a, R>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, R: std::io::Read> Iterator for StreamFindIter<'a, R>
fn next(self: &mut Self) -> Option<Result<Match, Error>>
impl<I> IntoIterator for StreamFindIter<'a, R>
fn into_iter(self: Self) -> I
impl<T> Any for StreamFindIter<'a, R>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for StreamFindIter<'a, R>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for StreamFindIter<'a, R>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for StreamFindIter<'a, R>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for StreamFindIter<'a, R>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for StreamFindIter<'a, R>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for StreamFindIter<'a, R>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>