Enum Anchored

enum Anchored

The type of anchored search to perform.

If an Aho-Corasick searcher does not support the anchored mode selected, then the search will return an error or panic, depending on whether a fallible or an infallible routine was called.

Variants

No

Run an unanchored search. This means a match may occur anywhere at or after the start position of the search up until the end position of the search.

Yes

Run an anchored search. This means that a match must begin at the start position of the search and end before the end position of the search.

Implementations

impl Anchored

fn is_anchored(self: &Self) -> bool

Returns true if and only if this anchor mode corresponds to an anchored search.

Example

use aho_corasick::Anchored;

assert!(!Anchored::No.is_anchored());
assert!(Anchored::Yes.is_anchored());

impl Clone for Anchored

fn clone(self: &Self) -> Anchored

impl Copy for Anchored

impl Debug for Anchored

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Anchored

impl Freeze for Anchored

impl PartialEq for Anchored

fn eq(self: &Self, other: &Anchored) -> bool

impl RefUnwindSafe for Anchored

impl Send for Anchored

impl StructuralPartialEq for Anchored

impl Sync for Anchored

impl Unpin for Anchored

impl UnsafeUnpin for Anchored

impl UnwindSafe for Anchored

impl<T> Any for Anchored

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Anchored

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Anchored

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Anchored

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Anchored

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Anchored

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Anchored

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Anchored

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Anchored

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>