Enum MatchErrorKind
enum MatchErrorKind
The underlying kind of a MatchError.
This is a non-exhaustive enum. That means new variants may be added in a semver-compatible release.
Variants
-
InvalidInputAnchored An error indicating that an anchored search was requested, but from a searcher that was built without anchored support.
-
InvalidInputUnanchored An error indicating that an unanchored search was requested, but from a searcher that was built without unanchored support.
-
UnsupportedStream { got: crate::util::search::MatchKind } An error indicating that a stream search was attempted on an Aho-Corasick automaton with an unsupported
MatchKind.-
UnsupportedOverlapping { got: crate::util::search::MatchKind } An error indicating that an overlapping search was attempted on an Aho-Corasick automaton with an unsupported
MatchKind.-
UnsupportedEmpty An error indicating that the operation requested doesn't support automatons that contain an empty pattern string.
Implementations
impl Clone for MatchErrorKind
fn clone(self: &Self) -> MatchErrorKind
impl Debug for MatchErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for MatchErrorKind
impl Freeze for MatchErrorKind
impl PartialEq for MatchErrorKind
fn eq(self: &Self, other: &MatchErrorKind) -> bool
impl RefUnwindSafe for MatchErrorKind
impl Send for MatchErrorKind
impl StructuralPartialEq for MatchErrorKind
impl Sync for MatchErrorKind
impl Unpin for MatchErrorKind
impl UnsafeUnpin for MatchErrorKind
impl UnwindSafe for MatchErrorKind
impl<T> Any for MatchErrorKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MatchErrorKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MatchErrorKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MatchErrorKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MatchErrorKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for MatchErrorKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for MatchErrorKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MatchErrorKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MatchErrorKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>