Struct Builder
struct Builder { ... }
A builder for constructing a packed searcher from a collection of patterns.
Example
This example shows how to use a builder to construct a searcher. By default, leftmost-first match semantics are used.
use ;
#
# if cfg! else
Implementations
impl Builder
fn new() -> BuilderCreate a new builder for constructing a multi-pattern searcher. This constructor uses the default configuration.
fn build(self: &Self) -> Option<Searcher>Build a searcher from the patterns added to this builder so far.
fn add<P: AsRef<[u8]>>(self: &mut Self, pattern: P) -> &mut BuilderAdd the given pattern to this set to match.
The order in which patterns are added is significant. Namely, when using leftmost-first match semantics, then when multiple patterns can match at a particular location, the pattern that was added first is used as the match.
If the number of patterns added exceeds the amount supported by packed searchers, then the builder will stop accumulating patterns and render itself inert. At this point, constructing a searcher will always return
None.fn extend<I, P>(self: &mut Self, patterns: I) -> &mut Builder where I: IntoIterator<Item = P>, P: AsRef<[u8]>Add the given iterator of patterns to this set to match.
The iterator must yield elements that can be converted into a
&[u8].The order in which patterns are added is significant. Namely, when using leftmost-first match semantics, then when multiple patterns can match at a particular location, the pattern that was added first is used as the match.
If the number of patterns added exceeds the amount supported by packed searchers, then the builder will stop accumulating patterns and render itself inert. At this point, constructing a searcher will always return
None.fn len(self: &Self) -> usizeReturns the number of patterns added to this builder.
fn minimum_len(self: &Self) -> usizeReturns the length, in bytes, of the shortest pattern added.
impl Clone for Builder
fn clone(self: &Self) -> Builder
impl Debug for Builder
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Builder
fn default() -> Builder
impl Freeze for Builder
impl RefUnwindSafe for Builder
impl Send for Builder
impl Sync for Builder
impl Unpin for Builder
impl UnsafeUnpin for Builder
impl UnwindSafe for Builder
impl<T> Any for Builder
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Builder
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Builder
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Builder
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Builder
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Builder
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Builder
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Builder
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Builder
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>