Struct FindOverlappingIter
struct FindOverlappingIter<'a, 'h>(_)
An iterator of overlapping matches in a particular haystack.
This iterator will report all possible matches in a particular haystack, even when the matches overlap.
This iterator is constructed via the AhoCorasick::find_overlapping_iter
and AhoCorasick::try_find_overlapping_iter methods.
The lifetime 'a refers to the lifetime of the AhoCorasick automaton.
The lifetime 'h refers to the lifetime of the haystack being searched.
Implementations
impl<'a, 'h> Debug for FindOverlappingIter<'a, 'h>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, 'h> Freeze for FindOverlappingIter<'a, 'h>
impl<'a, 'h> Iterator for FindOverlappingIter<'a, 'h>
fn next(self: &mut Self) -> Option<Match>
impl<'a, 'h> RefUnwindSafe for FindOverlappingIter<'a, 'h>
impl<'a, 'h> Send for FindOverlappingIter<'a, 'h>
impl<'a, 'h> Sync for FindOverlappingIter<'a, 'h>
impl<'a, 'h> Unpin for FindOverlappingIter<'a, 'h>
impl<'a, 'h> UnsafeUnpin for FindOverlappingIter<'a, 'h>
impl<'a, 'h> UnwindSafe for FindOverlappingIter<'a, 'h>
impl<I> IntoIterator for FindOverlappingIter<'a, 'h>
fn into_iter(self: Self) -> I
impl<T> Any for FindOverlappingIter<'a, 'h>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FindOverlappingIter<'a, 'h>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FindOverlappingIter<'a, 'h>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for FindOverlappingIter<'a, 'h>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for FindOverlappingIter<'a, 'h>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FindOverlappingIter<'a, 'h>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FindOverlappingIter<'a, 'h>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>