Struct MatchError

struct MatchError(_)

An error that occurred during an Aho-Corasick search.

An error that occurs during a search is limited to some kind of misconfiguration that resulted in an illegal call. Stated differently, whether an error occurs is not dependent on the specific bytes in the haystack.

Examples of misconfiguration:

When the std feature is enabled, this implements the std::error::Error trait.

Implementations

impl MatchError

fn new(kind: MatchErrorKind) -> MatchError

Create a new error value with the given kind.

This is a more verbose version of the kind-specific constructors, e.g., MatchError::unsupported_stream.

fn kind(self: &Self) -> &MatchErrorKind

Returns a reference to the underlying error kind.

fn invalid_input_anchored() -> MatchError

Create a new "invalid anchored search" error. This occurs when the caller requests an anchored search but where anchored searches aren't supported.

This is the same as calling MatchError::new with a MatchErrorKind::InvalidInputAnchored kind.

fn invalid_input_unanchored() -> MatchError

Create a new "invalid unanchored search" error. This occurs when the caller requests an unanchored search but where unanchored searches aren't supported.

This is the same as calling MatchError::new with a MatchErrorKind::InvalidInputUnanchored kind.

fn unsupported_stream(got: MatchKind) -> MatchError

Create a new "unsupported stream search" error. This occurs when the caller requests a stream search while using an Aho-Corasick automaton with a match kind other than MatchKind::Standard.

The match kind given should be the match kind of the automaton. It should never be MatchKind::Standard.

fn unsupported_overlapping(got: MatchKind) -> MatchError

Create a new "unsupported overlapping search" error. This occurs when the caller requests an overlapping search while using an Aho-Corasick automaton with a match kind other than MatchKind::Standard.

The match kind given should be the match kind of the automaton. It should never be MatchKind::Standard.

fn unsupported_empty() -> MatchError

Create a new "unsupported empty pattern" error. This occurs when the caller requests a search for which matching an automaton that contains an empty pattern string is not supported.

impl Clone for MatchError

fn clone(self: &Self) -> MatchError

impl Debug for MatchError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for MatchError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for MatchError

impl Error for MatchError

impl Freeze for MatchError

impl PartialEq for MatchError

fn eq(self: &Self, other: &MatchError) -> bool

impl RefUnwindSafe for MatchError

impl Send for MatchError

impl StructuralPartialEq for MatchError

impl Sync for MatchError

impl Unpin for MatchError

impl UnsafeUnpin for MatchError

impl UnwindSafe for MatchError

impl<T> Any for MatchError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MatchError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MatchError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MatchError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MatchError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for MatchError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for MatchError

fn to_string(self: &Self) -> String

impl<T, U> Into for MatchError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MatchError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MatchError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>